(sec_tstrait_docs_mainpage)=

# Tstrait documentation

tstrait is an open-source Python package for simulating quantitative traits.

```{eval-rst}
.. grid:: 2

   .. grid-item-card:: Introduction
      :img-top: _static/index-images/tstrait.svg

      Are you new to tstrait? The introduction page contains an introduction to tstrait
      and an overview of quantitative trait simulation in tstrait.

      +++

      .. button-ref:: intro
         :expand:
         :color: secondary
         :click-parent:

         To the introduction page

   .. grid-item-card:: Quick start
      :img-top: _static/index-images/sample-sim.svg

      The quick start page provides information on the key concepts of tstrait
      with fully worked examples.

      +++

      .. button-ref:: quickstart
         :expand:
         :color: secondary
         :click-parent:

         To the quick start page

   .. grid-item-card:: Tree Sequences
      :img-top: _static/index-images/tree-seq.svg

      This guide introduces a succinct tree sequence, which is an efficient way to
      store and process millions of DNA sequences.

      +++

      .. button-ref:: tskit-tutorials:what_is
         :expand:
         :color: secondary
         :click-parent:

         To the tree sequence guide

   .. grid-item-card:: API Reference
      :img-top: _static/index-images/api.svg

      The API reference guide contains a detailed description of the tstrait API.
      The reference describes how the methods work and which parameters can be used.
      It assumes that you have an understanding of the key concepts.

      +++

      .. button-ref:: api
         :expand:
         :color: secondary
         :click-parent:

         To the API reference guide
```
